pub struct FilterGraph {
pub primitives: SmallVec<[FilterPrimitive; 1]>,
pub output: FilterId,
/* private fields */
}Expand description
A directed acyclic graph (DAG) of filter operations.
The graph represents a pipeline of filter primitives where outputs of some
primitives can be used as inputs to others. Each primitive has a unique FilterId.
Fields
primitives: SmallVec<[FilterPrimitive; 1]>All filter primitives in the graph, stored in insertion order.
output: FilterIdThe final output filter ID whose result is the output of this graph.
Implementations
Sourceimpl FilterGraph
impl FilterGraph
Sourcepub fn add(
&mut self,
primitive: FilterPrimitive,
_inputs: Option<FilterInputs>,
) -> FilterId
pub fn add( &mut self, primitive: FilterPrimitive, _inputs: Option<FilterInputs>, ) -> FilterId
Add a filter primitive with optional inputs.
Returns a FilterId that can be referenced by other primitives.
Automatically updates the accumulated source and filter expansion requirements.
Sourcepub fn set_output(&mut self, output: FilterId)
pub fn set_output(&mut self, output: FilterId)
Set the output filter for the graph.
Sourcepub fn filter_expansion(&self, transform: &Affine) -> Rect
pub fn filter_expansion(&self, transform: &Affine) -> Rect
The filter expansion of all filters in the graph, see Filter::filter_expansion.
Sourcepub fn source_expansion(&self, transform: &Affine) -> Rect
pub fn source_expansion(&self, transform: &Affine) -> Rect
The source expansion of all filters in the graph, see Filter::source_expansion.