Drawable

Trait Drawable 

pub trait Drawable {
    // Required method
    fn bbox(&self, strips: &[Strip]) -> Option<RectU16>;
}
A drawable object that can report its bounding box.

Required Methods

fn bbox(&self, strips: &[Strip]) -> Option<RectU16>

Return the tile-aligned bounding box of the given object, if it has one.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors