pub trait Splat4thExt<S> {
// Required method
fn splat_4th(self) -> Self;
}Expand description
Splatting every 4th element in the vector, used for splatting the alpha value of a color to all lanes.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".